@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2025 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.2.90. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.3. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
@@ -307,12 +307,19 @@ settings* settings::_c2b_global_settings = 0;
 
 */
 
+bool settings::isConsoleCheckMode(const int argc, char** argv)
+{
+    for (int i = 0; i < argc; ++i)
+        if (strcmp(argv[i], "--c2binfo") == 0 || strcmp(argv[i], "--test") == 0)
+            return true;
+    return false;
+}
+
 bool settings::isConsoleMode(const int argc, char** argv)
 {
     for (int i = 0; i < argc; ++i)
         if (strcmp(argv[i], "--html-annote") == 0 || strcmp(argv[i], "--doc2bib") == 0 ||
-            strcmp(argv[i], "--txt2bib") == 0 || strcmp(argv[i], "--index") == 0 || strcmp(argv[i], "--c2binfo") == 0 ||
-            strcmp(argv[i], "--test") == 0)
+            strcmp(argv[i], "--txt2bib") == 0 || strcmp(argv[i], "--index") == 0)
             return true;
     return false;
 }
